Contributing
============

Basic method to contribute a change
-----------------------------------

Dyndnsc is under active development, and contributions are more than welcome!

#. Check for open issues or open a fresh issue to start a discussion around a bug
   on the `issue tracker <https://github.com/infothrill/python-dyndnsc/issues>`_.
#. Fork `the repository <https://github.com/infothrill/python-dyndnsc>`_ and start making your
   changes to a new branch.
#. Write a test which shows that the bug was fixed.
#. Send a pull request and bug the maintainer until it gets merged and published. :)
   Make sure to add yourself to `AUTHORS <https://github.com/infothrill/python-dyndnsc/blob/master/AUTHORS>`_.


Idioms to keep in mind
----------------------

* keep amount of external dependencies low, i.e. if it can be done using the
  standard library, do it using the standard library
* do not prefer specific operating systems, i.e. even if we love Linux, we
  shall not make other suffer from our personal choice
* write unittests

Also, keep these :pep:`20` idioms in mind:

#. Beautiful is better than ugly.
#. Explicit is better than implicit.
#. Simple is better than complex.
#. Complex is better than complicated.
#. Readability counts.
